@@ -32,6 +32,10 @@ else
     MURANO_API_URL="$MURANO_SERVICE_PROTOCOL://$MURANO_SERVICE_HOST:$MURANO_SERVICE_PORT"
 fi
 
+HORIZON_URL="http://${KEYSTONE_SERVICE_HOST}/dashboard"
+
+DASHBOARD_FUNCTIONAL_CONFIG_DIR=$MURANO_DASHBOARD_DIR/muranodashboard/tests/functional/config
+
 # create_murano_accounts() - Set up common required murano accounts
 #
 # Tenant      User       Roles
@@ -166,11 +170,8 @@ function configure_murano {
     mkdir_chown_stack "$MURANO_CONF_DIR"
 
     # Generate Murano configuration file and configure common parameters.
-    oslo-config-generator --namespace keystonemiddleware.auth_token \
-                          --namespace murano \
-                          --namespace oslo.db \
-                          --namespace oslo.messaging \
-                          > $MURANO_CONF_FILE
+    oslo-config-generator --config-file $MURANO_DIR/etc/oslo-config-generator/murano.conf --output-file $MURANO_CONF_FILE
+
     cp $MURANO_DIR/etc/murano/murano-paste.ini $MURANO_CONF_DIR
 
     cleanup_murano
@@ -248,10 +249,8 @@ function set_packages_service_backend() {
 function configure_murano_cfapi {
 
     # Generate Murano configuration file and configure common parameters.
-    oslo-config-generator --namespace keystonemiddleware.auth_token \
-                          --namespace murano.cfapi \
-                          --namespace oslo.db \
-                          > $MURANO_CFAPI_CONF_FILE
+    oslo-config-generator --config-file $MURANO_DIR/etc/oslo-config-generator/murano-cfapi.conf --output-file $MURANO_CFAPI_CONF_FILE
+
     cp $MURANO_DIR/etc/murano/murano-cfapi-paste.ini $MURANO_CONF_DIR
 
     configure_service_broker
@@ -457,10 +456,6 @@ function configure_murano_tempest_plugin() {
         echo_summary "Configuring Murano Tempest plugin"
         # Set murano service availability flag
         iniset $TEMPEST_CONFIG service_available murano "True"
-        # Running tempest in isolation will using tempest user.
-        if sudo id -u tempest >/dev/null 2>&1; then
-            sudo chown -R tempest:stack $MURANO_DIR/murano_tempest_tests
-        fi
         if is_service_enabled murano-cfapi; then
             # Enable Service Broker tests if cfapi enabled and set murano-cfapi service availability flag
             iniset $TEMPEST_CONFIG service_available murano_cfapi "True"
@@ -528,10 +523,26 @@ MURANO_REPOSITORY_URL=${MURANO_REPOSITORY_URL:-'http://apps.openstack.org/api/v1
 function configure_murano_dashboard() {
     configure_local_settings_py
 
+    configure_dashboard_functional_config
+
     restart_apache_server
 }
 
 
+function configure_dashboard_functional_config() {
+    cp $DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf.sample $DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf
+    sed -e "s%\(^\s*horizon_url\s*=\).*$%\1 $HORIZON_URL%" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s%\(^\s*murano_url\s*=\).*$%\1 $MURANO_API_URL%" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s/\(^\s*user\s*=\).*$/\1 $OS_USERNAME/" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s/\(^\s*password\s*=\).*$/\1 $OS_PASSWORD/" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s/\(^\s*tenant\s*=\).*$/\1 $OS_PROJECT_NAME/" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s%\(^\s*keystone_url\s*=\).*$%\1 $KEYSTONE_SERVICE_URI/v3%" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+
+    echo_summary "Show the DASHBOARD_FUNCTIONAL_CONFIG"
+    cat $DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf
+}
+
+
 function configure_local_settings_py() {
     local horizon_config_part=$(mktemp)
 
