@@ -15,10 +15,20 @@
 #    under the License.
 
 import os
-import sys
 
 import eventlet
 
+if os.name == 'nt':
+    # eventlet monkey patching causes subprocess.Popen to fail on Windows
+    # when using pipes due to missing non blocking I/O support
+    eventlet.monkey_patch(os=False)
+else:
+    eventlet.monkey_patch()
+
+
+import sys
+
+from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_service import service
 
@@ -28,13 +38,6 @@ from murano.common import engine
 CONF = config.CONF
 
 
-if os.name == 'nt':
-    # eventlet monkey patching causes subprocess.Popen to fail on Windows
-    # when using pipes due to missing non blocking I/O support
-    eventlet.monkey_patch(os=False)
-else:
-    eventlet.monkey_patch()
-
 # If ../murano/__init__.py exists, add ../ to Python search path, so that
 # it will override what happens to be installed in /usr/(local/)lib/python...
 root = os.path.join(os.path.abspath(__file__), os.pardir, os.pardir, os.pardir)
@@ -47,9 +50,11 @@ def main():
         config.parse_args()
 
         logging.setup(CONF, 'murano')
-        launcher = service.ServiceLauncher(CONF)
-        launcher.launch_service(engine.get_rpc_service())
-
+        workers = CONF.engine.engine_workers
+        if not workers:
+            workers = processutils.get_worker_count()
+        launcher = service.launch(CONF,
+                                  engine.EngineService(), workers=workers)
         launcher.wait()
     except RuntimeError as e:
         sys.stderr.write("ERROR: %s\n" % e)
