@@ -173,7 +173,12 @@ networking_opts = [
 stats_opts = [
     cfg.IntOpt('period', default=5,
                help=_('Statistics collection interval in minutes.'
-                      'Default value is 5 minutes.'))
+                      'Default value is 5 minutes.')),
+    cfg.IntOpt('env_audit_period', default=60,
+               help=_('Environment audit interval in minutes. '
+                      'Default value is 60 minutes.')),
+    cfg.BoolOpt('env_audit_enabled', default=True,
+                help=_('Whether environment audit events enabled'))
 ]
 
 engine_opts = [
@@ -215,6 +220,12 @@ engine_opts = [
                       'for legacy behavior using murano-api) or glance '
                       '(stands for glance-glare artifact service)'),
                deprecated_group='packages_opts'),
+
+    cfg.StrOpt('signing_key', default='~/.ssh/id_rsa',
+               help=_('Path to RSA key for agent message signing')),
+
+    cfg.StrOpt('agent_source', default='murano-agent',
+               help=_('pip URL/package spec for murano-agent')),
 ]
 
 # TODO(sjmc7): move into engine opts?
