@@ -43,9 +43,20 @@ class NoMethodFound(Exception):
         super(NoMethodFound, self).__init__('Method "%s" is not found' % name)
 
 
-class NoClassFound(Exception):
+class NoPropertyFound(Exception):
     def __init__(self, name):
-        super(NoClassFound, self).__init__('Class "%s" is not found' % name)
+        super(NoPropertyFound, self).__init__(
+            'Property "%s" is not found' % name)
+
+
+class NoClassFound(Exception):
+    def __init__(self, name, packages=None):
+        if packages is None:
+            packages = []
+        packages = ', '.join("{0}/{1}".format(p.name, p.version)
+                             for p in packages)
+        super(NoClassFound, self).__init__(
+            'Class "{0}" is not found in {1}'.format(name, packages))
 
 
 class NoPackageFound(Exception):
@@ -66,16 +77,20 @@ class NoObjectFoundError(Exception):
             'Object "%s" is not found in object store' % object_id)
 
 
+class MethodNotExposed(Exception):
+    pass
+
+
 class AmbiguousMethodName(Exception):
     def __init__(self, name):
         super(AmbiguousMethodName, self).__init__(
-            'Found more that one method "%s"' % name)
+            'Found more than one method "%s"' % name)
 
 
 class AmbiguousClassName(Exception):
     def __init__(self, name):
         super(AmbiguousClassName, self).__init__(
-            'Found more that one version of class "%s"' % name)
+            'Found more than one version of class "%s"' % name)
 
 
 class DslContractSyntaxError(Exception):
@@ -111,7 +126,7 @@ class PropertyAccessError(Exception):
 class AmbiguousPropertyNameError(PropertyAccessError):
     def __init__(self, name):
         super(AmbiguousPropertyNameError, self).__init__(
-            'Found more that one property "%s"' % name)
+            'Found more than one property "%s"' % name)
 
 
 class NoWriteAccess(PropertyAccessError):
@@ -149,3 +164,19 @@ class UninitializedPropertyAccessError(PropertyAccessError):
 
 class CircularExpressionDependenciesError(Exception):
     pass
+
+
+class InvalidLhsTargetError(Exception):
+    def __init__(self, target):
+        super(InvalidLhsTargetError, self).__init__(
+            'Invalid assignment target "%s"' % target)
+
+
+class InvalidInheritanceError(Exception):
+    pass
+
+
+class ObjectDestroyedError(Exception):
+    def __init__(self, obj):
+        super(ObjectDestroyedError, self).__init__(
+            'Object {0} is already destroyed'.format(obj))
