@@ -12,7 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import types
+
+import six
 
 from murano.dsl import constants
 from murano.dsl import dsl_exception
@@ -24,9 +25,8 @@ from murano.dsl import yaql_expression
 
 class CodeBlock(expressions.DslExpression):
     def __init__(self, body):
-        if not isinstance(body, types.ListType):
-            body = [body]
-        self.code_block = map(expressions.parse_expression, body)
+        body = helpers.list_value(body)
+        self.code_block = list(map(expressions.parse_expression, body))
 
     def execute(self, context):
         for expr in self.code_block:
@@ -140,7 +140,7 @@ class WhileDoMacro(expressions.DslExpression):
 
 class ForMacro(expressions.DslExpression):
     def __init__(self, For, In, Do):
-        if not isinstance(For, types.StringTypes):
+        if not isinstance(For, six.string_types):
             raise exceptions.DslSyntaxError(
                 'For value must be of string type')
         self._code = CodeBlock(Do)
@@ -180,7 +180,7 @@ class RepeatMacro(expressions.DslExpression):
 
 class MatchMacro(expressions.DslExpression):
     def __init__(self, Match, Value, Default=None):
-        if not isinstance(Match, types.DictionaryType):
+        if not isinstance(Match, dict):
             raise exceptions.DslSyntaxError(
                 'Match value must be of dictionary type')
         self._switch = Match
@@ -189,7 +189,7 @@ class MatchMacro(expressions.DslExpression):
 
     def execute(self, context):
         match_value = helpers.evaluate(self._value, context)
-        for key, value in self._switch.iteritems():
+        for key, value in self._switch.items():
             if key == match_value:
                 CodeBlock(value).execute(context)
                 return
@@ -199,7 +199,7 @@ class MatchMacro(expressions.DslExpression):
 
 class SwitchMacro(expressions.DslExpression):
     def __init__(self, Switch, Default=None):
-        if not isinstance(Switch, types.DictionaryType):
+        if not isinstance(Switch, dict):
             raise exceptions.DslSyntaxError(
                 'Switch value must be of dictionary type')
         self._switch = Switch
@@ -207,7 +207,7 @@ class SwitchMacro(expressions.DslExpression):
 
     def execute(self, context):
         matched = False
-        for key, value in self._switch.iteritems():
+        for key, value in self._switch.items():
             if helpers.evaluate(key, context):
                 matched = True
                 CodeBlock(value).execute(context)
