@@ -21,10 +21,8 @@ import heatclient.client as hclient
 import heatclient.exc as heat_exc
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 
 from murano.common import auth_utils
-from murano.common.i18n import _LW
 from murano.dsl import dsl
 from murano.dsl import helpers
 from murano.dsl import session_local_storage
@@ -71,7 +69,7 @@ class HeatStack(object):
     def _create_client(session, region_name):
         parameters = auth_utils.get_session_client_parameters(
             service_type='orchestration', region=region_name,
-            conf=CONF.heat, session=session)
+            conf='heat', session=session)
         return hclient.Client('1', **parameters)
 
     @property
@@ -81,11 +79,11 @@ class HeatStack(object):
     @staticmethod
     @session_local_storage.execution_session_memoize
     def _get_client(region_name):
-        session = auth_utils.get_client_session(conf=CONF.heat)
+        session = auth_utils.get_client_session(conf='heat')
         return HeatStack._create_client(session, region_name)
 
     def _get_token_client(self):
-        ks_session = auth_utils.get_token_client_session(conf=CONF.heat)
+        ks_session = auth_utils.get_token_client_session(conf='heat')
         return self._create_client(ks_session, self._region_name)
 
     def current(self):
@@ -147,7 +145,7 @@ class HeatStack(object):
 
     @staticmethod
     def _remove_system_params(parameters):
-        return dict((k, v) for k, v in six.iteritems(parameters) if
+        return dict((k, v) for k, v in parameters.items() if
                     not k.startswith('OS::'))
 
     def _get_status(self):
@@ -252,7 +250,7 @@ class HeatStack(object):
                         else:
                             self.delete()
             except heat_exc.HTTPConflict as e:
-                LOG.warning(_LW('Conflicting operation: {msg}').format(msg=e))
+                LOG.warning('Conflicting operation: {msg}'.format(msg=e))
                 eventlet.sleep(3)
             else:
                 break
@@ -300,11 +298,11 @@ class HeatStack(object):
                     lambda status: status in ('DELETE_COMPLETE', 'NOT_FOUND'),
                     wait_progress=True)
             except heat_exc.NotFound:
-                LOG.warning(_LW('Stack {stack_name} already deleted?')
+                LOG.warning('Stack {stack_name} already deleted?'
                             .format(stack_name=self._name))
                 break
             except heat_exc.HTTPConflict as e:
-                LOG.warning(_LW('Conflicting operation: {msg}').format(msg=e))
+                LOG.warning('Conflicting operation: {msg}'.format(msg=e))
                 eventlet.sleep(3)
             else:
                 break
