@@ -20,11 +20,10 @@ import neutronclient.v2_0.client as nclient
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import uuidutils
-import retrying
+import tenacity
 
 from murano.common import auth_utils
 from murano.common import exceptions as exc
-from murano.common.i18n import _LI
 from murano.dsl import dsl
 from murano.dsl import helpers
 from murano.dsl import session_local_storage
@@ -35,33 +34,35 @@ LOG = logging.getLogger(__name__)
 
 @dsl.name('io.murano.system.NetworkExplorer')
 class NetworkExplorer(object):
-    def __init__(self, this):
+    def __init__(self, this, region_name=None):
         session = helpers.get_execution_session()
         self._project_id = session.project_id
         self._settings = CONF.networking
         self._available_cidrs = self._generate_possible_cidrs()
-        self._owner = this.find_owner('io.murano.Environment')
+        self._region = this.find_owner('io.murano.CloudRegion')
+        self._region_name = region_name
 
     @staticmethod
     @session_local_storage.execution_session_memoize
     def _get_client(region_name):
-        neutron_settings = CONF.neutron
         return nclient.Client(**auth_utils.get_session_client_parameters(
-            service_type='network', region=region_name, conf=neutron_settings
+            service_type='network', region=region_name, conf='neutron'
         ))
 
     @property
     def _client(self):
-        region = None if self._owner is None else self._owner['region']
+        region = self._region_name or (
+            None if self._region is None else self._region['name'])
         return self._get_client(region)
 
     # NOTE(starodubcevna): to avoid simultaneous router requests we use retry
     # decorator with random delay 1-10 seconds between attempts and maximum
     # delay time 30 seconds.
-    @retrying.retry(retry_on_exception=lambda e: isinstance(e,
-                    exc.RouterInfoException),
-                    wait_random_min=1000, wait_random_max=10000,
-                    stop_max_delay=30000)
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(exc.RouterInfoException),
+        stop=tenacity.stop_after_delay(30),
+        wait=tenacity.wait_random(min=1, max=10),
+        reraise=True)
     def get_default_router(self):
         router_name = self._settings.router_name
 
@@ -95,7 +96,7 @@ class NetworkExplorer(object):
                 }
                 router = self._client.create_router(
                     body=body_data).get('router')
-                LOG.info(_LI('Created router: {id}').format(id=router['id']))
+                LOG.info('Created router: {id}'.format(id=router['id']))
                 return router['id']
             else:
                 raise KeyError('Router %s was not found' % router_name)
@@ -107,10 +108,11 @@ class NetworkExplorer(object):
         return router_id
 
     def get_available_cidr(self, router_id, net_id):
-        """Uses hash of network IDs to minimize the collisions:
-        different nets will attempt to pick different cidrs out of available
+        """Uses hash of network IDs to minimize the collisions
+
+        Different nets will attempt to pick different cidrs out of available
         range.
-        If the cidr is taken will pick another one
+        If the cidr is taken will pick another one.
         """
         taken_cidrs = self._get_cidrs_taken_by_router(router_id)
         id_hash = hash(net_id)
@@ -147,7 +149,7 @@ class NetworkExplorer(object):
         # For each router this network is connected to
         # check if the router has external_gateway set
         for router_port in router_ports:
-            ext_net_id = self.getExternalNetworkIdForRouter(
+            ext_net_id = self.get_external_network_id_for_router(
                 router_port.get('device_id'))
             if ext_net_id:
                 return ext_net_id
@@ -191,6 +193,5 @@ class NetworkExplorer(object):
     def list_ports(self):
         return self._client.list_ports()['ports']
 
-    @session_local_storage.execution_session_memoize
     def list_neutron_extensions(self):
         return self._client.list_extensions()['extensions']
