@@ -12,13 +12,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+__all__ = [
+    'list_opts',
+    'list_cfapi_opts',
+]
 
 import copy
 import itertools
+from keystoneauth1 import loading as ks_loading
 
 import oslo_service.sslutils
 
-import murano.api.middleware.ssl
+import murano.common.cf_config
 import murano.common.config
 import murano.common.wsgi
 
@@ -32,22 +37,44 @@ def build_list(opt_list):
 _opt_lists = [
     ('engine', murano.common.config.engine_opts),
     ('rabbitmq', murano.common.config.rabbit_opts),
-    ('heat', murano.common.config.heat_opts),
-    ('neutron', murano.common.config.neutron_opts),
-    ('keystone', murano.common.config.keystone_opts),
-    ('murano', murano.common.config.murano_opts),
+    ('heat',
+     murano.common.config.heat_opts +
+     ks_loading.get_session_conf_options()),
+    ('neutron',
+     murano.common.config.neutron_opts +
+     ks_loading.get_session_conf_options()),
+    ('murano', murano.common.config.murano_opts +
+     ks_loading.get_session_conf_options()),
+    ('glare',
+     murano.common.config.glare_opts +
+     ks_loading.get_session_conf_options()),
+    ('mistral',
+     murano.common.config.mistral_opts +
+     ks_loading.get_session_conf_options()),
     ('networking', murano.common.config.networking_opts),
     ('stats', murano.common.config.stats_opts),
-    ('packages_opts', murano.common.config.packages_opts),
+    ('murano_auth',
+     murano.common.config.murano_auth_opts +
+     ks_loading.get_session_conf_options() +
+     ks_loading.get_auth_common_conf_options() +
+     ks_loading.get_auth_plugin_conf_options('password') +
+     ks_loading.get_auth_plugin_conf_options('v2password') +
+     ks_loading.get_auth_plugin_conf_options('v3password')),
     (None, build_list([
         murano.common.config.metadata_dir,
         murano.common.config.bind_opts,
         murano.common.config.file_server,
         murano.common.wsgi.wsgi_opts,
-        murano.api.middleware.ssl.ssl_middleware_opts
     ])),
 ]
 
+_cfapi_opt_lists = [
+    ('cfapi', murano.common.cf_config.cfapi_opts),
+    ('glare',
+     murano.common.config.glare_opts +
+     ks_loading.get_session_conf_options())
+]
+
 _opt_lists.extend(oslo_service.sslutils.list_opts())
 
 
@@ -68,3 +95,8 @@ def list_opts():
     :returns: a list of (group_name, opts) tuples
     """
     return [(g, copy.deepcopy(o)) for g, o in _opt_lists]
+
+
+def list_cfapi_opts():
+    """Return a list of oslo_config options available in service broker."""
+    return [(g, copy.deepcopy(o)) for g, o in _cfapi_opt_lists]
