@@ -14,12 +14,12 @@
 # limitations under the License.
 
 import logging
-import urllib
 
 import fixtures
 import mock
 from oslo_utils import timeutils
 import routes
+from six.moves import urllib
 import webob
 
 from murano.api.v1 import request_statistics
@@ -43,7 +43,9 @@ def test_with_middleware(self, middleware, func, req, *args, **kwargs):
 
 
 class FakeLogMixin(object):
-    """Allow logs to be tested (rather than just disabling
+    """Allows logs to be tested
+
+    Allow logs to be tested (rather than just disabling
     logging. This is taken from heat
     """
     def setup_logging(self):
@@ -89,11 +91,13 @@ class MuranoApiTestCase(base.MuranoWithDBTestCase, FakeLogMixin):
         super(MuranoApiTestCase, self).tearDown()
         timeutils.utcnow.override_time = None
 
-    def _stub_uuid(self, values=[]):
+    def _stub_uuid(self, values=None):
         class FakeUUID(object):
             def __init__(self, v):
                 self.hex = v
 
+        if values is None:
+            values = []
         mock_uuid4 = mock.patch('uuid.uuid4').start()
         mock_uuid4.side_effect = [FakeUUID(v) for v in values]
         return mock_uuid4
@@ -111,6 +115,7 @@ class ControllerTest(object):
         # cfg.CONF.set_default('host', 'server.test')
         self.api_version = '1.0'
         self.tenant = 'test_tenant'
+        self.user = 'test_user'
         self.mock_policy_check = None
         self.mapper = routes.Mapper()
         self.api = router.API(self.mapper)
@@ -128,7 +133,9 @@ class ControllerTest(object):
         self._policy_check_expectations = []
         self._actual_policy_checks = []
 
-        def wrap_policy_check(rule, ctxt, target={}, **kwargs):
+        def wrap_policy_check(rule, ctxt, target=None, **kwargs):
+            if target is None:
+                target = {}
             self._actual_policy_checks.append((rule, target))
             return real_policy_check(rule, ctxt, target=target, **kwargs)
 
@@ -153,6 +160,8 @@ class ControllerTest(object):
     def _simple_request(self, path, params=None, method='GET',
                         user=DEFAULT_USER, tenant=DEFAULT_TENANT):
         """Returns a request with a fake but valid-looking context
+
+        Returns a request with a fake but valid-looking context
         and sets the request environment variables. If `params` is given,
         it should be a dictionary or sequence of tuples.
         """
@@ -160,7 +169,7 @@ class ControllerTest(object):
         environ['REQUEST_METHOD'] = method
 
         if params:
-            qs = urllib.urlencode(params)
+            qs = urllib.parse.urlencode(params)
             environ['QUERY_STRING'] = qs
 
         req = wsgi.Request(environ)
@@ -184,13 +193,16 @@ class ControllerTest(object):
 
     def _delete(self, path, params=None, user=DEFAULT_USER,
                 tenant=DEFAULT_TENANT):
-        params = params or {}
+        if params is None:
+            params = {}
         return self._simple_request(path, params=params, method='DELETE',
                                     user=user, tenant=tenant)
 
     def _data_request(self, path, data, content_type='application/json',
-                      method='POST', params={},
+                      method='POST', params=None,
                       user=DEFAULT_USER, tenant=DEFAULT_TENANT):
+        if params is None:
+            params = {}
         environ = self._environ(path)
         environ['REQUEST_METHOD'] = method
 
@@ -202,25 +214,39 @@ class ControllerTest(object):
         req.body = data
 
         if params:
-            qs = urllib.urlencode(params)
+            qs = urllib.parse.urlencode(params)
             environ['QUERY_STRING'] = qs
 
         return req
 
-    def _post(self, path, data, content_type='application/json', params={},
+    def _post(self, path, data, content_type='application/json', params=None,
               user=DEFAULT_USER, tenant=DEFAULT_TENANT):
+        if params is None:
+            params = {}
         return self._data_request(path, data, content_type, params=params,
                                   user=user, tenant=tenant)
 
-    def _put(self, path, data, content_type='application/json', params={},
+    def _put(self, path, data, content_type='application/json', params=None,
              user=DEFAULT_USER, tenant=DEFAULT_TENANT):
+        if params is None:
+            params = {}
         return self._data_request(path, data, content_type, method='PUT',
                                   params=params, user=user, tenant=tenant)
 
+    def _patch(self, path, data,
+               content_type='application/murano-packages-json-patch',
+               params=None, user=DEFAULT_USER, tenant=DEFAULT_TENANT):
+        if params is None:
+            params = {}
+        return self._data_request(path, data, content_type, method='PATCH',
+                                  params=params, user=user, tenant=tenant)
+
     def _set_policy_rules(self, rules):
         policy.set_rules(rules, default_rule='default')
 
-    def expect_policy_check(self, action, target={}):
+    def expect_policy_check(self, action, target=None):
+        if target is None:
+            target = {}
         self._policy_check_expectations.append((action, target))
 
     def _assert_policy_checks(self):
