@@ -22,6 +22,7 @@ import six
 import testtools
 
 from murano.cmd import test_runner
+from murano import version
 
 CONF = cfg.CONF
 logging.register_options(CONF)
@@ -36,13 +37,10 @@ class TestCaseShell(testtools.TestCase):
                             'project_name': 'test',
                             'auth_url': 'http://localhost:5000'}
         self.args = ['test-runner.py']
-        for k, v in self.auth_params.iteritems():
+        for k, v in self.auth_params.items():
             k = '--os-' + k.replace('_', '-')
             self.args.extend([k, v])
 
-        sys.stdout = six.StringIO()
-        sys.stderr = six.StringIO()
-
         self.useFixture(fixtures.MonkeyPatch('keystoneclient.v3.client.Client',
                                              mock.MagicMock))
         dirs = [os.path.dirname(__file__),
@@ -56,39 +54,51 @@ class TestCaseShell(testtools.TestCase):
 
     def override_config(self, name, override, group=None):
         CONF.set_override(name, override, group)
+        CONF.set_override('use_stderr', True)
         self.addCleanup(CONF.clear_override, name, group)
 
     def shell(self, cmd_args=None, exitcode=0):
-        orig = sys.stdout
-        orig_stderr = sys.stderr
-        sys.stdout = six.StringIO()
-        sys.stderr = six.StringIO()
+        stdout = six.StringIO()
+        stderr = six.StringIO()
         args = self.args
         if cmd_args:
             cmd_args = cmd_args.split()
             args.extend(cmd_args)
-        with mock.patch.object(sys, 'argv', args):
-            result = self.assertRaises(SystemExit, test_runner.main)
-            self.assertEqual(result.code, exitcode,
-                             'Command finished with error.')
-        stdout = sys.stdout.getvalue()
-        sys.stdout.close()
-        sys.stdout = orig
-        stderr = sys.stderr.getvalue()
-        sys.stderr.close()
-        sys.stderr = orig_stderr
+        with mock.patch.object(sys, 'stdout', stdout):
+            with mock.patch.object(sys, 'stderr', stderr):
+                with mock.patch.object(sys, 'argv', args):
+                    result = self.assertRaises(SystemExit, test_runner.main)
+                    self.assertEqual(result.code, exitcode,
+                                     'Command finished with error.')
+        stdout = stdout.getvalue()
+        stderr = stderr.getvalue()
         return (stdout, stderr)
 
     def test_help(self):
         stdout, _ = self.shell('--help')
-        usage = """usage: murano-test-runner [-h] [-v] [--config-file CONFIG_FILE]
+        usage = """usage: murano-test-runner [-h] [--config-file CONFIG_FILE]
                           [--os-auth-url OS_AUTH_URL]
                           [--os-username OS_USERNAME]
                           [--os-password OS_PASSWORD]
-                          [--os-project-name OS_PROJECT_NAME] [-p PACKAGE]
-                          [-l [</path1, /path2> [</path1, /path2> ...]]]
+                          [--os-project-name OS_PROJECT_NAME]
+                          [-l [</path1, /path2> [</path1, /path2> ...]]] [-v]
+                          [--version]
+                          <PACKAGE_FQN>
                           [<testMethod1, className.testMethod2> [<testMethod1, className.testMethod2"""  # noqa
-        self. assertIn(usage, stdout)
+        self.assertIn(usage, stdout)
+
+    def test_version(self):
+        stdout, stderr = self.shell('--version')
+        if six.PY3:
+            output = stdout
+        else:
+            output = stderr
+        self.assertIn(version.version_string, output)
+
+    @mock.patch.object(test_runner, 'LOG')
+    def test_increase_verbosity(self, mock_log):
+        self.shell('io.murano.test.MyTest1 -v')
+        mock_log.logger.setLevel.assert_called_with(logging.DEBUG)
 
     @mock.patch('keystoneclient.v3.client.Client')
     def test_os_params_replaces_config(self, mock_client):
@@ -96,60 +106,80 @@ class TestCaseShell(testtools.TestCase):
         importutils.import_module('keystonemiddleware.auth_token')
         self.override_config('admin_user', 'new_value', 'keystone_authtoken')
 
-        self.shell('-p io.murano.test.MyTest1 io.murano.test.MyTest2')
+        self.shell('io.murano.test.MyTest1 io.murano.test.MyTest2')
 
         mock_client.assert_has_calls([mock.call(**self.auth_params)])
 
     def test_package_all_tests(self):
-        _, stderr = self.shell('-p io.murano.test.MyTest1')
+        _, stderr = self.shell('io.murano.test.MyTest1 -v')
         # NOTE(efedorova): May be, there is a problem with test-runner, since
         # all logs are passed to stderr
-        self.assertIn('io.murano.test.MyTest1.testSimple1.....OK', stderr)
-        self.assertIn('io.murano.test.MyTest1.testSimple2.....OK', stderr)
-        self.assertIn('io.murano.test.MyTest2.testSimple1.....OK', stderr)
-        self.assertIn('io.murano.test.MyTest2.testSimple2.....OK', stderr)
+        self.assertIn('Test io.murano.test.MyTest1.testSimple1 successful',
+                      stderr)
+        self.assertIn('Test io.murano.test.MyTest1.testSimple2 successful',
+                      stderr)
+        self.assertIn('Test io.murano.test.MyTest2.testSimple1 successful',
+                      stderr)
+        self.assertIn('Test io.murano.test.MyTest2.testSimple2 successful',
+                      stderr)
         self.assertNotIn('thisIsNotAtestMethod', stderr)
 
     def test_package_by_class(self):
         _, stderr = self.shell(
-            '-p io.murano.test.MyTest1 io.murano.test.MyTest2')
+            'io.murano.test.MyTest1 io.murano.test.MyTest2 -v')
 
-        self.assertNotIn('io.murano.test.MyTest1.testSimple1.....OK', stderr)
-        self.assertNotIn('io.murano.test.MyTest1.testSimple2.....OK', stderr)
-        self.assertIn('io.murano.test.MyTest2.testSimple1.....OK', stderr)
-        self.assertIn('io.murano.test.MyTest2.testSimple2.....OK', stderr)
+        self.assertNotIn('Test io.murano.test.MyTest1.testSimple1 successful',
+                         stderr)
+        self.assertNotIn('Test io.murano.test.MyTest1.testSimple2 successful',
+                         stderr)
+        self.assertIn('Test io.murano.test.MyTest2.testSimple1 successful',
+                      stderr)
+        self.assertIn('Test io.murano.test.MyTest2.testSimple2 successful',
+                      stderr)
 
     def test_package_by_test_name(self):
         _, stderr = self.shell(
-            '-p io.murano.test.MyTest1 testSimple1')
+            'io.murano.test.MyTest1 testSimple1 -v')
 
-        self.assertIn('io.murano.test.MyTest1.testSimple1.....OK', stderr)
-        self.assertNotIn('io.murano.test.MyTest1.testSimple2.....OK', stderr)
-        self.assertIn('io.murano.test.MyTest2.testSimple1.....OK', stderr)
-        self.assertNotIn('io.murano.test.MyTest2.testSimple2.....OK', stderr)
+        self.assertIn('Test io.murano.test.MyTest1.testSimple1 successful',
+                      stderr)
+        self.assertNotIn('Test io.murano.test.MyTest1.testSimple2 successful',
+                         stderr)
+        self.assertIn('Test io.murano.test.MyTest2.testSimple1 successful',
+                      stderr)
+        self.assertNotIn('Test io.murano.test.MyTest2.testSimple2 successful',
+                         stderr)
 
     def test_package_by_test_and_class_name(self):
         _, stderr = self.shell(
-            '-p io.murano.test.MyTest1 io.murano.test.MyTest2.testSimple1')
+            'io.murano.test.MyTest1 io.murano.test.MyTest2.testSimple1 -v')
 
-        self.assertNotIn('io.murano.test.MyTest1.testSimple1.....OK', stderr)
-        self.assertNotIn('io.murano.test.MyTest1.testSimple2.....OK', stderr)
-        self.assertIn('io.murano.test.MyTest2.testSimple1.....OK', stderr)
-        self.assertNotIn('io.murano.test.MyTest2.testSimple2.....OK', stderr)
+        self.assertNotIn('Test io.murano.test.MyTest1.testSimple1 successful',
+                         stderr)
+        self.assertNotIn('Test io.murano.test.MyTest1.testSimple2 successful',
+                         stderr)
+        self.assertIn('Test io.murano.test.MyTest2.testSimple1 successful',
+                      stderr)
+        self.assertNotIn('Test io.murano.test.MyTest2.testSimple2 successful',
+                         stderr)
 
     def test_service_methods(self):
         _, stderr = self.shell(
-            '-p io.murano.test.MyTest1 io.murano.test.MyTest1.testSimple1')
+            'io.murano.test.MyTest1 io.murano.test.MyTest1.testSimple1 -v')
         self.assertIn('Executing: io.murano.test.MyTest1.setUp', stderr)
         self.assertIn('Executing: io.murano.test.MyTest1.tearDown', stderr)
 
     def test_package_is_not_provided(self):
-        _, stderr = self.shell(exitcode=1)
-        self.assertIn('ERROR: Package name is required parameter.', stderr)
+        _, stderr = self.shell(exitcode=2)
+        if six.PY3:
+            err = 'the following arguments are required: '
+        else:
+            err = 'too few arguments'
+        self.assertIn('murano-test-runner: error: %s' % err, stderr)
 
     def test_wrong_parent(self):
         _, stderr = self.shell(
-            '-p io.murano.test.MyTest1 io.murano.test.MyTest3', exitcode=1)
+            'io.murano.test.MyTest1 io.murano.test.MyTest3 -v', exitcode=1)
         self.assertIn('Class io.murano.test.MyTest3 is not inherited from'
                       ' io.murano.test.TestFixture. Skipping it.', stderr)
         self.assertIn('No tests found for execution.', stderr)
