@@ -14,6 +14,7 @@
 import uuid
 
 from oslo_db import exception as db_exception
+from six.moves import range
 from webob import exc
 
 from murano.db.catalog import api
@@ -39,7 +40,7 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
 
     def _stub_package(self, **kwargs):
         base = {
-            'archive': "archive blob here",
+            'archive': b"archive blob here",
             'fully_qualified_name': 'com.example.package',
             'type': 'class',
             'author': 'OpenStack',
@@ -48,7 +49,7 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
             'description': 'some text',
             'is_public': False,
             'tags': ['tag1', 'tag2'],
-            'logo': "logo blob here",
+            'logo': b"logo blob here",
             'ui_definition': '{}',
         }
         base.update(**kwargs)
@@ -108,7 +109,9 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
         self.assertEqual(pkg_a_id + pkg_z_id, [r.id for r in res])
 
     def test_pagination_backwards(self):
-        """Creates 10 packages with unique names and iterates backwards,
+        """Tests backwards pagination
+
+        Creates 10 packages with unique names and iterates backwards,
         checking that package order is correct.
         """
         pkgs = []
@@ -148,7 +151,9 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
         self.assertEqual(0, len(res))
 
     def test_pagination(self):
-        """Creates 10 packages with unique names and iterates through them,
+        """Tests that package order is correct
+
+        Creates 10 packages with unique names and iterates through them,
         checking that package order is correct.
         """
 
@@ -181,8 +186,10 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
         self.assertEqual(0, len(res))
 
     def test_pagination_loops_through_names(self):
-        """Creates 10 packages with the same display name and iterates through them,
-        checking that package are not skipped.
+        """Tests that packages with same display name are not skipped
+
+        Creates 10 packages with the same display name and iterates
+        through them, checking that package are not skipped.
         """
 
         for dummy in range(10):
@@ -205,6 +212,31 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
         res = api.package_search({'marker': marker}, self.context, limit=4)
         self.assertEqual(0, len(res))
 
+    def test_package_search_search_order(self):
+        pkg1 = api.package_upload(
+            self._stub_package(
+                fully_qualified_name=str(uuid.uuid4()),
+                name='mysql',
+                description='awcloud'),
+            self.tenant_id)
+        pkg2 = api.package_upload(
+            self._stub_package(
+                fully_qualified_name=str(uuid.uuid4()),
+                name='awcloud',
+                description='mysql'),
+            self.tenant_id)
+        api.package_upload(
+            self._stub_package(
+                tags=[],
+                fully_qualified_name=str(uuid.uuid4())),
+            self.tenant_id)
+
+        res = api.package_search(
+            {'search': 'mysql'}, self.context)
+        self.assertEqual(2, len(res))
+        self.assertEqual(pkg1.name, res[0].name)
+        self.assertEqual(pkg2.description, res[1].description)
+
     def test_package_search_search(self):
         pkg1 = api.package_upload(
             self._stub_package(
@@ -373,7 +405,7 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
         self.assertEqual(2, len(res))
 
         for cat in res:
-            self.assertTrue(cat.id is not None)
+            self.assertIsNotNone(cat.id)
             self.assertTrue(cat.name.startswith('cat'))
 
     def test_package_upload(self):
@@ -476,7 +508,7 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
         patch = self.get_change('replace', ['is_public'], True)
         api.package_update(id, [patch], self.context)
         package = api.package_get(id, self.context)
-        self.assertEqual(True, package.is_public)
+        self.assertTrue(package.is_public)
 
     def test_package_update_public_public_fqn_violation(self):
         id1 = api.package_upload(self._stub_package(), self.tenant_id).id
@@ -520,3 +552,27 @@ class CatalogDBTestCase(base.MuranoWithDBTestCase):
         category_names.reverse()
         page = api.categories_list({'sort_dir': 'desc'})
         self.assertEqual(category_names, [c.name for c in page])
+
+    def test_category_get_delete_error(self):
+        category_id = 12
+        self.assertRaises(exc.HTTPNotFound, api.category_get, category_id)
+        self.assertRaises(exc.HTTPNotFound, api.category_delete, category_id)
+
+    def test_get_categories_error(self):
+        category_names = ['cat1', 'cat2', 'cat3', 'cat4', 'cat5']
+        cat_session = None
+        self.assertRaises(exc.HTTPBadRequest, api._get_categories,
+                          category_names, cat_session)
+
+    def test_authorize_package_delete_error(self):
+        values = self._stub_package()
+        package = api.package_upload(values, self.tenant_id)
+        self.assertRaises(exc.HTTPForbidden, api._authorize_package, package,
+                          self.context_2)
+        self.assertRaises(exc.HTTPForbidden,
+                          api.package_delete, package.id, self.context_2)
+        id = package.id
+        patch = self.get_change('replace', ['is_public'], False)
+        api.package_update(id, [patch], self.context)
+        self.assertRaises(exc.HTTPForbidden, api._authorize_package, package,
+                          self.context_2, allow_public=True)
